loadsmith-thunderstore 0.3.0

Thunderstore API client, index backends, and r2z format for the loadsmith mod-manager library
docs.rs failed to build loadsmith-thunderstore-0.3.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: loadsmith-thunderstore-0.3.1

Thunderstore API client, index backends, and r2z format for the loadsmith mod-manager library.

This is an internal crate of the [loadsmith] workspace. Most consumers should depend on the loadsmith facade crate instead of using this crate directly.

Examples

use loadsmith_core::PackageId;
use loadsmith_thunderstore::PackageIdExt;

let id = PackageId::new("Author-Name");
let ident = id.into_ts_ident().unwrap();
assert_eq!(ident.to_string(), "Author-Name");